list = [
['jp2', '0000000c6a502020', 'jpeg2000 image files'],
['3gp', '0000001466747970', '3gpp multimedia files'],
['3gp5', '0000001866747970', 'mpeg-4 video files'],
['3gp', '0000002066747970', '3gpp2 multimedia files'],
['m4a', '00000020667479704d3441', 'apple audio and video files'],
['spl', '00000100', 'windows icon|printer spool file'],
['ico', '00000100', 'windows icon|printer spool file'],
['mpg', '000001b3', 'mpeg video file'],
['vob', '000001ba', 'dvd video file'],
['mpg', '000001ba', 'dvd video file'],
['wb2', '00000200', 'quattropro spreadsheet'],
['cur', '00000200', 'windows cursor'],
['wk1', '0000020006040600', 'lotus 1-2-3 (v1)'],
['wk3', '00001a0000100400', 'lotus 1-2-3 (v3)'],
['wk5', '00001a0002100400', 'lotus 1-2-3 (v4|v5)'],
['wk4', '00001a0002100400', 'lotus 1-2-3 (v4|v5)'],
['123', '00001a00051004', 'lotus 1-2-3 (v9)'],
['qxd', '00004949585052', 'quark express (intel)'],
['qxd', '00004d4d585052', 'quark express (motorola)'],
['hlp', '0000ffffffff', 'windows help file_1'],
['mny', '000100004d534953414d204461746162617365', 'microsoft money file'],
['accdb', '000100005374616e6461726420414345204442', 'microsoft access 2007'],
['mdb', '000100005374616e64617264204a6574204442', 'microsoft access'],
['aba', '00014241', 'palm address book archive'],
['dba', '00014244', 'palm datebook archive'],
['db', '0006156100000002000004d200001000', 'netscape navigator (v4) database'],
['fli', '0011', 'flic animation'],
['*', '001400000102', 'bios details in ram'],
['snm', '001e849000000000', 'netscape communicator (v4) mail folder'],
['ppt', '006e1ef0', 'powerpoint presentation subheader_1'],
['mdf', '010f0000', 'sql data base'],
['tr1', '0110', 'novell lanalyzer capture file'],
['rgb', '01da01010003', 'silicon graphics rgb bitmap'],
['drw', '01ff02040302', 'micrografx vector graphic file'],
['dss', '02647373', 'digital speech standard file'],
['dat', '03', 'mapinfo native data format'],
['db3', '03', 'dbase iii file'],
['qph', '03000000', 'quicken price history'],
['adx', '0300000041505052', 'approach index file'],
['db4', '04', 'dbase iv file'],
['*', '04000000', 'info2 windows recycle bin_1'],
['*', '05000000', 'info2 windows recycle bin_2'],
['drw', '07', 'generic drawing programs'],
['skf', '07534b46', 'skincrafter skin'],
['dtd', '0764743264647464', 'designtools 2d design file'],
['db', '08', 'dbase iv or dbfast configuration file'],
['xls', '0908100000060500', 'excel spreadsheet subheader_1'],
['pcx', '0a020101', 'zsoft paintbrush file_1'],
['pcx', '0a030101', 'zsoft paintbrush file_2'],
['pcx', '0a050101', 'zsoft paintbrush file_3'],
['mp', '0ced', 'monochrome picture tiff bitmap'],
['doc', '0d444f43', 'deskmate document'],
['nri', '0e4e65726f49534f', 'nero cd compilation'],
['wks', '0e574b53', 'deskmate worksheet'],
['ppt', '0f00e803', 'powerpoint presentation subheader_2'],
['pf', '1100000053434341', 'windows prefetch file'],
['ntf', '1a0000', 'lotus notes database template'],
['nsf', '1a0000040000', 'lotus notes database'],
['arc', '1a02', 'lh archive (old vers.|type 1)'],
['arc', '1a03', 'lh archive (old vers.|type 2)'],
['arc', '1a04', 'lh archive (old vers.|type 3)'],
['arc', '1a08', 'lh archive (old vers.|type 4)'],
['arc', '1a09', 'lh archive (old vers.|type 5)'],
['pak', '1a0b', 'pak compressed archive file'],
['eth', '1a350100', 'winpharoah capture file'],
['mkv', '1a45dfa393428288', 'matroska stream file'],
['dat', '1a52545320434f4d', 'runtime software disk image'],
['ws', '1d7d', 'wordstar version 5.0|6.0 document'],
['gz', '1f8b08', 'gzip archive file'],
['tar.z', '1f9d90', 'compressed tape archive_1'],
['tar.z', '1fa0', 'compressed tape archive_2'],
['ain', '2112', 'ain compressed archive'],
['lib', '213c617263683e0a', 'unix archiver (ar)|ms program library common object file format (coff)'],
['msi', '2320', 'cerius2 file'],
['vmdk', '23204469736b2044', 'vmware 4 virtual disk description'],
['dsp', '23204d6963726f73', 'ms developer studio project file'],
['amr', '2321414d52', 'adaptive multi-rate acelp codec (gsm)'],
['hdr', '233f52414449414e', 'radiance high dynamic range image file'],
['sav', '24464c3240282329', 'spss data file'],
['eps', '252150532d41646f', 'encapsulated postscript file'],
['pdf', '25504446', 'pdf file'],
['fdf', '25504446', 'pdf file'],
['hqx', '2854686973206669', 'binhex 4 compressed archive'],
['log', '2a2a2a2020496e73', 'symantec wise installer log'],
['lha', '2d6c68', 'compressed archive'],
['lzh', '2d6c68', 'compressed archive'],
['ivr', '2e524543', 'realplayer video file (v11+)'],
['rm', '2e524d46', 'realmedia streaming media'],
['rmvb', '2e524d46', 'realmedia streaming media'],
['ra', '2e524d4600000012', 'realaudio file'],
['ra', '2e7261fd00', 'realaudio streaming media'],
['au', '2e736e64', 'next|sun microsystems audio file'],
['cat', '30', 'ms security catalog file'],
['evt', '300000004c664c65', 'windows event viewer file'],
['wmv', '3026b2758e66cf11', 'windows media audio|video file'],
['wma', '3026b2758e66cf11', 'windows media audio|video file'],
['asf', '3026b2758e66cf11', 'windows media audio|video file'],
['ntf', '30314f52444e414e', 'national transfer format map'],
['*', '3037303730', 'cpio archive'],
['wri', '31be', 'ms write file_1'],
['wri', '32be', 'ms write file_2'],
['*', '34cdb2a1', 'tcpdump capture file'],
['7z', '377abcaf271c', '7-zip compressed file'],
['*', '37e45396c9dbd607', 'zisofs compressed file'],
['psd', '38425053', 'photoshop image'],
['sle', '3a56455253494f4e', 'surfplan kite project file'],
['asx', '3c', 'advanced stream redirector'],
['xdr', '3c', 'biztalk xml-data reduced schema'],
['dci', '3c21646f63747970', 'aol html mail'],
['manifest', '3c3f786d6c2076657273696f6e3d', 'windows visual stylesheet'],
['xml', '3c3f786d6c2076657273696f6e3d22312e30223f3e', 'user interface language'],
['msc', '3c3f786d6c2076657273696f6e3d22312e30223f3e0d0a3c4d4d435f436f6e736f6c6546696c6520436f6e736f6c65566572', 'mmc snap-in control file'],
['mif', '3c4d616b65724669', 'adobe framemaker'],
['fm', '3c4d616b65724669', 'adobe framemaker'],
['wb3', '3e000300feff090006', 'quatro pro for windows 7.0'],
['gid', '3f5f0300', 'windows help file_2'],
['hlp', '3f5f0300', 'windows help file_2'],
['enl', '40404020000040404040', 'endnote library file'],
['dwg', '41433130', 'generic autocad drawing'],
['*', '41435344', 'aol parameter|info files'],
['sle', '414376', 'steganos virtual secure drive'],
['syw', '414d594f', 'harvard graphics symbol graphic'],
['aby', '414f4c', 'aol config files'],
['pfc', '414f4c', 'aol config files'],
['idx', '414f4c', 'aol config files'],
['ind', '414f4c', 'aol config files'],
['bag', '414f4c', 'aol config files'],
['abi', '414f4c', 'aol config files'],
['bag', '414f4c2046656564', 'aol and aim buddy list'],
['aby', '414f4c4442', 'aol address book'],
['idx', '414f4c4442', 'aol user configuration'],
['ind', '414f4c494458', 'aol client preferences|settings file'],
['abi', '414f4c494e444558', 'aol address book index'],
['org', '414f4c564d313030', 'aol personal file cabinet'],
['pfc', '414f4c564d313030', 'aol personal file cabinet'],
['dat', '415647365f496e74', 'avg6 integrity database'],
['arc', '41724301', 'freearc compressed file'],
['vcf', '424547494e3a5643', 'vcard'],
['bin', '424c4932323351', 'speedtouch router firmware'],
['dib', '424d', 'bitmap image'],
['bmp', '424d', 'bitmap image'],
['prc', '424f4f4b4d4f4249', 'palmpilot resource file'],
['tbz2', '425a68', 'bzip2 compressed archive'],
['tb2', '425a68', 'bzip2 compressed archive'],
['tar.bz2', '425a68', 'bzip2 compressed archive'],
['bz2', '425a68', 'bzip2 compressed archive'],
['rtd', '43232b44a4434da5', 'ragtime document'],
['cbd', '434246494c45', 'wordperfect dictionary'],
['iso', '4344303031', 'iso-9660 cd disc image'],
['clb', '434d5831', 'corel binary metafile'],
['clb', '434f4d2b', 'com+ catalog'],
['vmdk', '434f5744', 'vmware 3 virtual disk'],
['cpt', '4350543746494c45', 'corel photopaint file_1'],
['cpt', '43505446494c45', 'corel photopaint file_2'],
['dat', '43524547', 'win9x registry hive'],
['cru', '43525553482076', 'crush compressed archive'],
['swf', '435753', 'shockwave flash file'],
['ctf', '436174616c6f6720', 'whereisit catalog'],
['dat', '436c69656e742055', 'ie history file'],
['db', '44424648', 'palm zire photo database'],
['dms', '444d5321', 'amiga diskmasher compressed archive'],
['adf', '444f53', 'amiga disk file'],
['ifo', '445644', 'dvd info file'],
['dvr', '445644', 'dvr-studio stream file'],
['cdr', '454c49544520436f', 'elite plus commander game file'],
['vcd', '454e545259564344', 'videovcd|vcdimager file'],
['mdi', '4550', 'ms document imaging file'],
['dat', '4552465353415645', 'easyrecovery saved state file'],
['e01', '455646090d0aff00', 'expert witness compression format'],
['evtx', '456c6646696c6500', 'windows vista event log'],
['qbb', '458600000600', 'quickbooks backup'],
['cpe', '464158434f564552', 'ms fax cover sheet'],
['flv', '464c56', 'flash video file'],
['aiff', '464f524d00', 'audio interchange file'],
['swf', '465753', 'shockwave flash player'],
['eml', '46726f6d', 'generic e-mail_2'],
['gif', '47494638', 'gif file'],
['pat', '47504154', 'gimp pattern file'],
['gx2', '475832', 'show partner graphics file'],
['sh3', '4848474231', 'harvard graphics presentation file'],
['hip', '48695021', 'houdini image file. three-dimensional modeling and animation'],
['tif', '492049', 'tiff file_1'],
['tiff', '492049', 'tiff file_1'],
['mp3', '494433', 'mp3 audio file'],
['koz', '49443303000000', 'sprint music store audio'],
['crw', '49491a0000004845', 'canon raw file'],
['tif', '49492a00', 'tiff file_2'],
['tiff', '49492a00', 'tiff file_2'],
['cab', '49536328', 'install shield compressed file'],
['hdr', '49536328', 'install shield compressed file'],
['lit', '49544f4c49544c53', 'ms reader ebook'],
['chi', '49545346', 'ms compiled html help file'],
['chm', '49545346', 'ms compiled html help file'],
['dat', '496e6e6f20536574', 'inno setup uninstall log'],
['jar', '4a4152435300', 'jarcs compressed archive'],
['jg', '4a47030e', 'aol art file_1'],
['jg', '4a47040e', 'aol art file_2'],
['vmdk', '4b444d', 'vmware 4 virtual disk'],
['kgb', '4b47425f61726368', 'kgb archive'],
['shd', '4b490000', 'win9x printer spool file'],
['*', '4b57414a88f027d1', 'kwaj (compressed) file'],
['lnk', '4c00000001140200', 'windows shortcut file'],
['obj', '4c01', 'ms coff relocatable object code'],
['hlp', '4c4e0200', 'windows help file_3'],
['gid', '4c4e0200', 'windows help file_3'],
['e01', '4c5646090d0aff00', 'logical file evidence format'],
['pdb', '4d2d5720506f636b', 'merriam-webster pocket dictionary'],
['mar', '4d41523100', 'mozilla archive'],
['mar', '4d415243', 'microsoft|msn marc archive'],
['mar', '4d41723000', 'mar compressed archive'],
['hdmp', '4d444d5093a7', 'windows dump file'],
['dmp', '4d444d5093a7', 'windows dump file'],
['mls', '4d494c4553', 'milestones project management file'],
['mls', '4d4c5357', 'skype localization data file'],
['tiff', '4d4d002a', 'tiff file_3'],
['tif', '4d4d002a', 'tiff file_3'],
['tiff', '4d4d002b', 'tiff file_4'],
['tif', '4d4d002b', 'tiff file_4'],
['mmf', '4d4d4d440000', 'yamaha synthetic music mobile application format'],
['nvram', '4d52564e', 'vmware bios state file'],
['cab', '4d534346', 'microsoft cabinet file'],
['snp', '4d534346', 'ms access snapshot viewer file'],
['ppz', '4d534346', 'powerpoint packaged presentation'],
['tlb', '4d53465402000100', 'ole|spss|visual c++ library file'],
['dvf', '4d535f564f494345', 'sony compressed voice file'],
['cdr', '4d535f564f494345', 'sony compressed voice file'],
['msv', '4d535f564f494345', 'sony compressed voice file'],
['midi', '4d546864', 'midi sound file'],
['mid', '4d546864', 'midi sound file'],
['dsn', '4d56', 'cd stomper pro label file'],
['mls', '4d56323134', 'milestones project management file_1'],
['mls', '4d563243', 'milestones project management file_2'],
['vbx', '4d5a', 'visualbasic application'],
['dll', '4d5a', 'windows|dos executable file'],
['com', '4d5a', 'windows|dos executable file'],
['sys', '4d5a', 'windows|dos executable file'],
['olb', '4d5a', 'ole object library'],
['ax', '4d5a', 'library cache file'],
['scr', '4d5a', 'screen saver'],
['ocx', '4d5a', 'activex|ole custom control'],
['olb', '4d5a', 'ole object library'],
['scr', '4d5a', 'screen saver'],
['ocx', '4d5a', 'activex|ole custom control'],
['acm', '4d5a', 'ms audio compression manager driver'],
['cpl', '4d5a', 'control panel application'],
['386', '4d5a', 'windows virtual device drivers'],
['qtx', '4d5a', 'windows|dos executable file'],
['vxd', '4d5a', 'windows virtual device drivers'],
['fon', '4d5a', 'font file'],
['qts', '4d5a', 'windows|dos executable file'],
['flt', '4d5a900003000000', 'audition graphic filter'],
['ax', '4d5a900003000000', 'directshow filter'],
['api', '4d5a900003000000', 'acrobat plug-in'],
['zap', '4d5a90000300000004000000ffff', 'zonealam data file'],
['pdb', '4d6963726f736f667420432f432b2b20', 'ms c++ debugging symbols file'],
['sln', '4d6963726f736f66742056697375616c', 'visual studio .net file'],
['wpl', '4d6963726f736f66742057696e646f7773204d6564696120506c61796572202d2d20', 'windows media player playlist'],
['dat', '4e41565452414646', 'tomtom traffic data'],
['jtp', '4e422a00', 'ms windows journal'],
['jnt', '4e422a00', 'ms windows journal'],
['nsf', '4e45534d1a01', 'nes sound file'],
['ntf', '4e49544630', 'national imagery transmission format file'],
['cod', '4e616d653a20', 'agent newsreader character map'],
['dbf', '4f504c4461746162', 'psion series 3 database'],
['ogx', '4f67675300020000', 'ogg vorbis codec compressed file'],
['ogv', '4f67675300020000', 'ogg vorbis codec compressed file'],
['ogg', '4f67675300020000', 'ogg vorbis codec compressed file'],
['oga', '4f67675300020000', 'ogg vorbis codec compressed file'],
['dw4', '4f7b', 'visio|displaywrite 4 text file'],
['idx', '5000000020000000', 'quicken quickfinder information file'],
['pgm', '50350a', 'portable graymap graphic'],
['pak', '5041434b', 'quake archive file'],
['dmp', '504147454455', 'windows memory dump'],
['pax', '504158', 'pax password protected bitmap'],
['dat', '50455354', 'pestpatrol data|scan strings'],
['pgd', '504750644d41494e', 'pgp disk image'],
['img', '504943540008', 'chromagraph graphics card bitmap'],
['sxw', '504b0304', 'openoffice documents'],
['cuix', '504b0304', 'customization files'],
['sxi', '504b0304', 'openoffice documents'],
['sxd', '504b0304', 'openoffice documents'],
['kwd', '504b0304', 'kword document'],
['ott', '504b0304', 'opendocument template'],
['odp', '504b0304', 'opendocument template'],
['xpt', '504b0304', 'exact packager models'],
['jar', '504b0304', 'java archive_1'],
['xpi', '504b0304', 'mozilla browser archive'],
['xlsx', '504b0304', 'ms office open xml format document'],
['odt', '504b0304', 'opendocument template'],
['pptx', '504b0304', 'ms office open xml format document'],
['sxc', '504b0304', 'staroffice spreadsheet'],
['docx', '504b0304', 'ms office open xml format document'],
['zip', '504b0304', 'pkzip archive_1'],
['wmz', '504b0304', 'windows media compressed skin file'],
['xps', '504b0304', 'xml paper specification file'],
['zip', '504b030414000100', 'zlock pro encrypted zip'],
['docx', '504b030414000600', 'ms office 2007 documents'],
['xlsx', '504b030414000600', 'ms office 2007 documents'],
['pptx', '504b030414000600', 'ms office 2007 documents'],
['jar', '504b030414000800', 'java archive_2'],
['zip', '504b0506', 'pkzip archive_2'],
['zip', '504b0708', 'pkzip archive_3'],
['zip', '504b4c495445', 'pklite archive'],
['zip', '504b537058', 'pksfx self-extracting archive'],
['grp', '504d4343', 'windows program manager group file'],
['dat', '504e4349554e444f', 'norton disk doctor undo file'],
['qel', '51454c20', 'qdl quicken data'],
['qemu', '514649', 'qcow disk image'],
['abd', '5157205665722e20', 'abd | qsd quicken data file'],
['qsd', '5157205665722e20', 'abd | qsd quicken data file'],
['dat', '52415a4154444231', 'shareaza (p2p) thumbnail'],
['reg', '52454745444954', 'winnt registry|registry undo files'],
['sud', '52454745444954', 'winnt registry|registry undo files'],
['ad', '5245564e554d3a2c', 'antenna data file'],
['4xm', '52494646', '4x movie video'],
['dat', '52494646', 'video cd mpeg movie'],
['cmx', '52494646', 'corel presentation exchange metadata'],
['cdr', '52494646', 'coreldraw document'],
['ds4', '52494646', 'micrografx designer graphic'],
['avi', '52494646', 'resource interchange file format'],
['ani', '52494646', 'windows animated cursor'],
['cda', '52494646', 'resource interchange file format'],
['qcp', '52494646', 'resource interchange file format'],
['rmi', '52494646', 'resource interchange file format'],
['wav', '52494646', 'resource interchange file format'],
['cap', '52545353', 'winnt netmon capture file'],
['rar', '526172211a0700', 'winrar compressed archive'],
['eml', '52657475726e2d50', 'generic e-mail_1'],
['ast', '5343486c', 'underground audio'],
['img', '53434d49', 'img software bitmap'],
['shw', '53484f57', 'harvard graphics presentation'],
['cpi', '53494554524f4e49', 'sietronics cpi xrd document'],
['sit', '5349542100', 'stuffit archive'],
['sdr', '534d415254445257', 'smartdraw drawing file'],
['cnv', '53514c4f434f4e56', 'db2 conversion file'],
['db', '53514c69746520666f726d6174203300', 'sqlite database file'],
['*', '535a2088f02733d1', 'qbasic szdd file'],
['*', '535a444488f02733', 'szdd file format'],
['sit', '5374756666497420', 'stuffit compressed archive'],
['cal', '537570657243616c', 'supercalc worksheet'],
['info', '5468697320697320', 'gnu info reader file'],
['uce', '55434558', 'unicode extensions'],
['ufa', '554641c6d2c1', 'ufa compressed archive'],
['dat', '55464f4f72626974', 'ufo capture map file'],
['pch', '564350434830', 'visual c precompiled header'],
['ctl', '56455253494f4e20', 'visual basic user-defined control file'],
['mif', '56657273696f6e20', 'mapinfo interchange format file'],
['dat', '574d4d50', 'walkman mp3 file'],
['ws2', '575332303030', 'wordstar for windows file'],
['zip', '57696e5a6970', 'winzip compressed archive'],
['lwp', '576f726450726f', 'lotus wordpro file'],
['eml', '582d', 'exchange e-mail'],
['cap', '58435000', 'packet sniffer files'],
['xpt', '5850434f4d0a5479', 'xpcom libraries'],
['bdr', '5854', 'ms publisher'],
['zoo', '5a4f4f20', 'zoo compressed archive'],
['ecf', '5b47656e6572616c', 'ms exchange configuration file'],
['vcw', '5b4d535643', 'visual c++ workbench info file'],
['dun', '5b50686f6e655d', 'dial-up networking file'],
['sam', '5b5645525d', 'lotus ami pro document_1'],
['cpx', '5b57696e646f7773', 'microsoft code page translation file'],
['cfg', '5b666c7473696d2e', 'flight simulator aircraft configuration'],
['sam', '5b7665725d', 'lotus ami pro document_2'],
['jar', '5f27a889', 'jar archive'],
['cas', '5f434153455f', 'encase case file'],
['cbk', '5f434153455f', 'encase case file'],
['arj', '60ea', 'arj compressed archive file'],
['*', '626567696e', 'uuencoded file'],
['*', '62706c697374', 'binary property list (plist)'],
['vhd', '636f6e6563746978', 'virtual pc hd image'],
['csh', '6375736800000002', 'photoshop custom shape'],
['p10', '64000000', 'intel proset|wireless profile'],
['dex', '6465780a30303900', 'dalvik (android) executable file'],
['au', '646e732e', 'audacity audio file'],
['dsw', '64737766696c65', 'ms visual studio workspace file'],
['shd', '66490000', 'winnt printer spool file'],
['flac', '664c614300000022', 'free lossless audio codec file'],
['mov', '66726565', 'quicktime movie_2'],
['shd', '67490000', 'win2000|xp printer spool file'],
['shd', '68490000', 'win server 2003 printer spool file'],
['dbb', '6c33336c', 'skype user data file'],
['mov', '6d646174', 'quicktime movie_3'],
['mov', '6d6f6f76', 'quicktime movie_1'],
['*', '6f3c', 'sms text (sim)'],
['mov', '706e6f74', 'quicktime movie_5'],
['dat', '72656766', 'winnt registry file'],
['ac', '72696666', 'sonic foundry acid music file'],
['ram', '727473703a2f2f', 'realmedia metafile'],
['mov', '736b6970', 'quicktime movie_6'],
['dat', '736c6821', 'allegro generic packfile (compressed)'],
['dat', '736c682e', 'allegro generic packfile (uncompressed)'],
['pdb', '736d5f', 'palmos supermemo'],
['cal', '737263646f636964', 'cals raster bitmap'],
['pdb', '737a657a', 'powerbasic debugger symbols'],
['prc', '74424d504b6e5772', 'pathway map file'],
['tar', '7573746172', 'tape archive'],
['flt', '76323030332e3130', 'qimage filter'],
['mov', '77696465', 'quicktime movie_4'],
['dmg', '78', 'macos x image file'],
['info', '7a626578', 'zoombrowser image index'],
['lgc', '7b0d0a6f20', 'windows application log'],
['lgd', '7b0d0a6f20', 'windows application log'],
['pwi', '7b5c707769', 'ms winmobile personal note'],
['rtf', '7b5c72746631', 'rtf file'],
['psp', '7e424b00', 'corel paint shop pro image'],
['*', '7f454c46', 'elf executable'],
['obj', '80', 'relocatable object code'],
['adx', '80000020031204', 'dreamcast audio'],
['wab', '813284c18505d011', 'outlook express address book (win95)'],
['wpf', '81cdab', 'wordperfect text'],
['png', '89504e470d0a1a0a', 'png image'],
['aw', '8a0109000000e108', 'ms answer wizard'],
['hap', '91334846', 'hamarsoft compressed archive'],
['skr', '9500', 'pgp secret keyring_1'],
['skr', '9501', 'pgp secret keyring_2'],
['gpg', '99', 'gpg public keyring'],
['pkr', '9901', 'pgp public keyring'],
['wab', '9ccbcb8d1375d211', 'outlook address file'],
['ppt', 'a0461df0', 'powerpoint presentation subheader_3'],
['*', 'a1b2c3d4', 'tcpdump (libpcap) capture file'],
['*', 'a1b2cd34', 'extended tcpdump (libpcap) capture file'],
['dat', 'a90d000000000000', 'access data ftk evidence'],
['qdf', 'ac9ebd8f0000', 'qdf quicken data'],
['*', 'aced', 'java serialization data'],
['pdb', 'aced000573720012', 'bgblitz position database file'],
['pwl', 'b04d4643', 'win95 password file'],
['dcx', 'b168de3a', 'pcx bitmap'],
['tib', 'b46e6844', 'acronis true image'],
['cal', 'b5a2b0b3b3b0a5b5', 'windows calendar'],
['wri', 'be000000ab', 'ms write file_3'],
['acs', 'c3abcdab', 'ms agent character file'],
['eps', 'c5d0d3c6', 'adobe encapsulated postscript'],
['lbk', 'c8007900', 'jeppesen flitelog file'],
['class', 'cafebabe', 'java bytecode'],
['*', 'cd20aaaa02000000', 'nav quarantined virus file'],
['doc', 'cf11e0a1b11ae100', 'perfect office document'],
['dbx', 'cfad12fe', 'outlook express e-mail folder'],
['vsd', 'd0cf11e0a1b11ae1', 'visio file'],
['db', 'd0cf11e0a1b11ae1', 'msworks database file'],
['opt', 'd0cf11e0a1b11ae1', 'developer studio file options file'],
['pub', 'd0cf11e0a1b11ae1', 'ms publisher file'],
['msi', 'd0cf11e0a1b11ae1', 'microsoft installer package'],
['msc', 'd0cf11e0a1b11ae1', 'microsoft common console document'],
['xla', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['sou', 'd0cf11e0a1b11ae1', 'visual studio solution user options file'],
['apr', 'd0cf11e0a1b11ae1', 'lotus|ibm approach 97 file'],
['wiz', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['ppt', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['pps', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['mtw', 'd0cf11e0a1b11ae1', 'minitab data file'],
['xla', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['sou', 'd0cf11e0a1b11ae1', 'visual studio solution user options file'],
['apr', 'd0cf11e0a1b11ae1', 'lotus|ibm approach 97 file'],
['wiz', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['ppt', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['pps', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['mtw', 'd0cf11e0a1b11ae1', 'minitab data file'],
['dot', 'd0cf11e0a1b11ae1', 'microsoft office document'],
['ftr', 'd20a0000', 'winpharoah filter file'],
['aut', 'd42a', 'aol history|typed url files'],
['arl', 'd42a', 'aol history|typed url files'],
['*', 'd4c3b2a1', 'windump (winpcap) capture file'],
['wmf', 'd7cdc69a', 'windows graphics metafile'],
['doc', 'dba52d00', 'word 2.0 file'],
['cpl', 'dcdc', 'corel color palette'],
['efx', 'dcfe', 'efax file'],
['info', 'e310000100000000', 'amiga icon'],
['pwl', 'e3828596', 'win98 password file'],
['one', 'e4525c7b8cd8a74d', 'ms onenote note'],
['com', 'e8', 'windows executable file_1'],
['sys', 'e8', 'windows executable file_1'],
['com', 'e9', 'windows executable file_2'],
['sys', 'e9', 'windows executable file_2'],
['com', 'eb', 'windows executable file_3'],
['sys', 'eb', 'windows executable file_3'],
['img', 'eb3c902a', 'gem raster file'],
['doc', 'eca5c100', 'word document subheader'],
['rpm', 'edabeedb', 'redhat package manager'],
['*', 'efbbbf', 'utf8 file'],
['db', 'fdffffff', 'thumbs.db subheader'],
['suo', 'fdffffff04', 'visual studio solution subheader'],
['ppt', 'fdffffff0e000000', 'powerpoint presentation subheader_4'],
['xls', 'fdffffff10', 'excel spreadsheet subheader_2'],
['ppt', 'fdffffff1c000000', 'powerpoint presentation subheader_5'],
['xls', 'fdffffff1f', 'excel spreadsheet subheader_3'],
['opt', 'fdffffff20', 'developer studio subheader'],
['xls', 'fdffffff22', 'excel spreadsheet subheader_4'],
['xls', 'fdffffff23', 'excel spreadsheet subheader_5'],
['xls', 'fdffffff28', 'excel spreadsheet subheader_6'],
['xls', 'fdffffff29', 'excel spreadsheet subheader_7'],
['ppt', 'fdffffff43000000', 'powerpoint presentation subheader_6'],
['ghs', 'feef', 'symantex ghost image file'],
['gho', 'feef', 'symantex ghost image file'],
['*', 'feff', 'utf-16|ucs-2 file'],
['sys', 'ff', 'windows executable'],
['wks', 'ff00020004040554', 'works for windows spreadsheet'],
['cpi', 'ff464f4e54', 'windows international code page'],
['sys', 'ff4b455942202020', 'keyboard driver file'],
['wpp', 'ff575043', 'wordperfect text and graphics'],
['wpg', 'ff575043', 'wordperfect text and graphics'],
['wpd', 'ff575043', 'wordperfect text and graphics'],
['wp6', 'ff575043', 'wordperfect text and graphics'],
['wp5', 'ff575043', 'wordperfect text and graphics'],
['wp', 'ff575043', 'wordperfect text and graphics'],
['jpe', 'ffd8ffe0', 'jpeg image'],
['jfif', 'ffd8ffe0', 'jpeg image'],
['jpe', 'ffd8ffe0', 'jpe image file - jpeg'],
['jfif', 'ffd8ffe0', 'jfif image file - jpeg'],
['jpg', 'ffd8ffe0', 'jpeg image'],
['jpeg', 'ffd8ffe0', 'jpeg image'],
['jpg', 'ffd8ffe1', 'digital camera jpg using exchangeable image file format (exif)'],
['jpeg', 'ffd8ffe2', 'cannon eos jpeg file'],
['jpeg', 'ffd8ffe3', 'samsung d500 jpeg file'],
['jpg', 'ffd8ffe8', 'still picture interchange file format (spiff)'],
['reg', 'fffe', 'windows registry file'],
['*', 'fffe0000', 'utf-32|ucs-4 file'],
['mof', 'fffe23006c006900', 'msinfo file'],
['sys', 'ffffffff', 'dos system driver'],
]